# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/01_card.ipynb.

# %% auto 0
__all__ = ['suits', 'ranks', 'Card']

# %% ../nbs/01_card.ipynb 2
from nbdev.showdoc import *
from fastcore.test import *
from fastcore.utils import *

# %% ../nbs/01_card.ipynb 3
suits= ["♣", "♦", "♥", "♠"]
ranks = [None, "A"] + [str(x) for x in range(2,11)] + ["J", "Q", "K"]

# %% ../nbs/01_card.ipynb 13
class Card:
    '''A playing card, created by passing in `rank` from `ranks` and `suit` from `suits`'''
    def __init__(self, 
                 suit:int, # An index into `suits`
                 rank:int): # An index into `ranks`
        self.suit, self.rank = suit, rank
    def __str__(self): return f"{ranks[self.rank]}{suits[self.suit]}"
    __repr__ = __str__
    def __eq__(self:'Card', a:'Card'): return (self.suit, self.rank)==(a.suit, a.rank)
    def __lt__(self:'Card', a:'Card'): return (self.suit, self.rank)<(a.suit, a.rank)
    def __gt__(self:'Card', a:'Card'): return (self.suit, self.rank)>(a.suit, a.rank)

# %% ../nbs/01_card.ipynb 16
# @patch - need "from fastcore.utils import *"
# def __eq__(self:Card, a:Card): return (self.suit, self.rank)==(a.suit, a.rank)



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/02_deck.ipynb.

# %% auto 0
__all__ = ['Deck', 'draw_n']

# %% ../nbs/02_deck.ipynb 2
from nbdev.showdoc import *
from fastcore.test import *
from fastcore.utils import *
import random

# %% ../nbs/02_deck.ipynb 3
from .card import *

# %% ../nbs/02_deck.ipynb 6
class Deck:
    '''A deck of 52 cards, not including jokers'''
    def __init__(self): self.cards = [Card(s,r) for s in range(4) for r in range(1,14)]
    def __len__(self): return len(self.cards)
    def __str__(self): return '; '.join(map(str, self.cards))
    def __contains__(self,card): return card in self.cards
    __repr__ = __str__
    
    def shuffle(self):
        "Shuffle the cards in this deck"
        random.shuffle(self.cards)
# psst! Hi dad!(Sophia)

# %% ../nbs/02_deck.ipynb 21
@patch
def pop(self:Deck,
        idx:int=-1): # The index of the card to remove, defaulting to the last one
        "Remove one card from deck"
        return self.cards.pop(idx)

# %% ../nbs/02_deck.ipynb 27
@patch
def remove(self:Deck,
           card:Card): # Card to remove
    "Remove `card` from the deck or raises exception if it is not there"
    self.cards.remove(card)

# %% ../nbs/02_deck.ipynb 33
def draw_n(n:int, # number of cards to draw
           replace:bool=True): # whether or not draw with replacement
    "Draw `n` cards, with replacement iif `replace`"
    d = Deck()
    d.shuffle()
    if replace: return [d.cards[random.choice(range(len(d.cards)))] for _ in range(n)]
    else: return d.cards[:n]



# Autogenerated by nbdev

d = { 'settings': { 'allowed_cell_metadata_keys': '',
                'allowed_metadata_keys': '',
                'audience': 'Developers',
                'author': 'Hung P. Do, PhD',
                'author_email': 'hdocmsu@gmail.com',
                'black_formatting': 'False',
                'branch': 'main',
                'clean_ids': 'True',
                'copyright': '@hdocmsu',
                'custom_sidebar': 'False',
                'description': 'A test project using nbdev',
                'doc_baseurl': '/nbdev_cards/',
                'doc_host': 'https://hdocmsu.github.io',
                'doc_path': '_docs',
                'git_url': 'https://github.com/hdocmsu/nbdev_cards/',
                'host': 'github',
                'jupyter_hooks': 'True',
                'keywords': 'nbdev',
                'language': 'English',
                'lib_name': 'nbdev-cards2022',
                'lib_path': 'nbdev_cards',
                'license': 'apache2',
                'min_python': '3.8',
                'nbs_path': 'nbs',
                'readme_nb': 'index.ipynb',
                'recursive': 'False',
                'status': '2',
                'title': 'cards',
                'tst_flags': 'notest',
                'user': 'hdocmsu',
                'version': '0.0.7'},
  'syms': { 'nbdev_cards.card': { 'nbdev_cards.card.Card': 'https://hdocmsu.github.io/nbdev_cards/nbdev_cards.card.html#card',
                                  'nbdev_cards.card.ranks': 'https://hdocmsu.github.io/nbdev_cards/nbdev_cards.card.html#ranks',
                                  'nbdev_cards.card.suits': 'https://hdocmsu.github.io/nbdev_cards/nbdev_cards.card.html#suits'},
            'nbdev_cards.deck': { 'nbdev_cards.deck.Deck': 'https://hdocmsu.github.io/nbdev_cards/nbdev_cards.deck.html#deck',
                                  'nbdev_cards.deck.Deck.pop': 'https://hdocmsu.github.io/nbdev_cards/nbdev_cards.deck.html#deck.pop',
                                  'nbdev_cards.deck.Deck.remove': 'https://hdocmsu.github.io/nbdev_cards/nbdev_cards.deck.html#deck.remove',
                                  'nbdev_cards.deck.Deck.shuffle': 'https://hdocmsu.github.io/nbdev_cards/nbdev_cards.deck.html#deck.shuffle',
                                  'nbdev_cards.deck.draw_n': 'https://hdocmsu.github.io/nbdev_cards/nbdev_cards.deck.html#draw_n'}}}